server_client_20141231_085104

### config2 : test_load_balance

Result | Function execution time | Total execution time
--- | --- | ---
Passed | 3.59284114838 sec | 4.84345579147 sec

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
qps | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 0.0
latency | 6.70 | 1.20 | 0.43 | 0.67 | 0.74 | 1.42 | 3.84 | 6.12 | 1.68

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 117.67 | 92.73 | 70.14 | 90.39 | 104.03 | 112.21 | 114.94 | 117.12 | 19.48
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | qps | mean lt 7.0 | 4.0
server1-perf | latency | p50 lt 0.3 | 0.671
server1-perf | latency | mean lt 0.33 | 1.20375
server2-perf | qps | mean lt 7.0 | None
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
client1-perf | qps | mean lt 2.0 | 1.0
client1-perf | latency | p50 lt 22.0 | 90.39
client1-perf | latency | mean lt 35.0 | 92.733
client2-perf | qps | mean lt 2.0 | None
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None